@@ -369,9 +369,12 @@ class GradescopeGrader:
 
         first_exam = True
         for exam in exams:
-            tmp_exam_json, tmp_template_questions, tmp_email_to_data_map, tmp_total = examtool.api.download.download(
-                exam
-            )
+            (
+                tmp_exam_json,
+                tmp_template_questions,
+                tmp_email_to_data_map,
+                tmp_total,
+            ) = examtool.api.download.download(exam)
 
             # Choose only the emails we want to keep.
             if emails:
@@ -1115,9 +1118,7 @@ class ExamtoolOutline:
                 question_id = question.get("id")
                 if question_id in id_question_ids:
                     print(f"Skipping {question_id} as it is an id question.")
-                    page += (
-                        1
-                    )  # Still need to increment this as it is still on the exam pdf.
+                    page += 1  # Still need to increment this as it is still on the exam pdf.
                     continue
                 pg.add_child(self.question_to_gso_question(grader, page, question))
                 gs_number_to_exam_q[f"{qid}.{sqid}"] = question
@@ -1170,8 +1171,8 @@ class QuestionGroup:
     def __init__(self, name: str, selected_rubric_items: [bool], gid: str = None):
         self.name = name
         self.selected_rubric_items = (
-            selected_rubric_items
-        )  # Bool array of selected items.
+            selected_rubric_items  # Bool array of selected items.
+        )
         self.gid = gid
         self.sids = set()
 
